pub struct PathParser { /* private fields */ }Expand description
A context object for parsing the extended path syntax.
Syntax
The extended path syntax is a super-set of the SVG path syntax, with support for extra per-endpoint data for custom attributes.
Wherever an endpoint is specified, the extended path syntax expects a sequence N extra numbers where N is the number of custom attributes.
For example with 1 custom attribute M 0 0 10 Q 1 1 2 2 20 L 3 3 30 reads as follows:
- Begin at endpoint position [0, 0] with custom attribute 10,
- quadratic bézier curve ending at endpoint [2, 2] custom attribute 20, with control point [1, 1],
- line to endpoint [3, 3] custom attribute 30.
Note that only endpoints have custom attributes, control points do not.
Implementations
Sourceimpl PathParser
impl PathParser
pub fn new() -> Self
pub fn parse<Iter, Builder>( &mut self, options: &ParserOptions, src: &mut Source<Iter>, output: &mut Builder, ) -> Result<(), ParseError>